@@ -241,7 +241,6 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
 
     mProxyModel = new TodoViewSortFilterProxyModel(preferences(), this);
     mProxyModel->setSourceModel(sModels->coloredTodoModel);
-    mProxyModel->setDynamicSortFilter(true);
     mProxyModel->setFilterKeyColumn(Akonadi::TodoModel::SummaryColumn);
     mProxyModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
     mProxyModel->setSortRole(Qt::EditRole);
@@ -420,14 +419,6 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
-    a = mItemPopupMenu->addAction(QIcon::fromTheme(QStringLiteral("view-pim-notes")),
-                                  i18nc("@action:inmenu", "Create Note for To-do"),
-                                  this,
-                                  qOverload<>(&TodoView::createNote));
-    a->setObjectName("createnote"_L1);
-    mItemPopupMenuReadWriteEntries << a;
-    mItemPopupMenuItemOnlyEntries << a;
-
     mItemPopupMenu->addSeparator();
 
     mCopyPopupMenu = new KDatePickerPopup(KDatePickerPopup::NoDate | KDatePickerPopup::DatePicker | KDatePickerPopup::Words, QDate::currentDate(), this);
@@ -1317,18 +1308,6 @@ void TodoView::createEvent()
     Q_EMIT createEvent(todoItem);
 }
 
-void TodoView::createNote()
-{
-    const QModelIndexList selection = mView->selectionModel()->selectedRows();
-    if (selection.size() != 1) {
-        return;
-    }
-
-    const auto todoItem = selection[0].data(Akonadi::TodoModel::TodoRole).value<Akonadi::Item>();
-
-    Q_EMIT createNote(todoItem);
-}
-
 #include "todoview.moc"
 
 #include "moc_todoview.cpp"
